@@ -1,7 +1,7 @@
 context("test-annotation-scale.R")
 
 test_that("scale bar parameters are generated correctly", {
-  load_longlake_data()
+  load_longlake_data(which = "longlake_depthdf")
   nc <- sf::read_sf(system.file("shape/nc.shp", package="sf"))
 
   expect_equal(
@@ -41,105 +41,102 @@ test_that("scale bar parameters are generated correctly", {
 })
 
 test_that("annotation scale works as intended", {
-  load_longlake_data()
+  load_longlake_data(which = "longlake_depthdf")
   nc <- sf::read_sf(system.file("shape/nc.shp", package="sf"))
 
   # defaults are ok
-  print(
+  vdiffr::expect_doppelganger(
+    "scale bar (defaults, coord_sf)",
     ggplot() +
       geom_sf(data = nc) +
-      annotation_scale() +
-      labs(caption = "defaults for annotation_scale() with coord_sf()")
+      annotation_scale()
   )
 
   expect_message(
-    print(
+    vdiffr::expect_doppelganger(
+      "scale bar (defaults, cartesian)",
       ggplot() +
-        geom_point(aes(x, y), data = data.frame(x = 0:4, y = -(0:4))) +
+        ggplot2::geom_point(aes(x, y), data = data.frame(x = 0:4, y = -(0:4))) +
         annotation_scale(pad_x = unit(0, "cm")) +
-        labs(caption = "defaults for annotation_scale() with non-coord_sf()") +
-        coord_fixed(expand = FALSE)
+        ggplot2::coord_fixed(expand = FALSE)
     ),
     "Using plotunit"
   )
 
 
-  print(
+  vdiffr::expect_doppelganger(
+    "scale bar (metric plotunit, cartesian)",
     ggplot() +
-      geom_point(aes(x, y), data = data.frame(x = 0:4/10, y = -(0:4)/10)) +
+      ggplot2::geom_point(aes(x, y), data = data.frame(x = 0:4/10, y = -(0:4)/10)) +
       annotation_scale(pad_x = unit(0, "cm"), plot_unit = "m") +
-      labs(caption = "mixing metric units") +
-      coord_fixed(expand = FALSE)
+      ggplot2::coord_fixed(expand = FALSE)
   )
 
-  print(
+  vdiffr::expect_doppelganger(
+    "scale bar (imperial plotunit)",
     ggplot() +
-      geom_point(aes(x, y), data = data.frame(x = 0:4, y = -(0:4))) +
+      ggplot2::geom_point(aes(x, y), data = data.frame(x = 0:4, y = -(0:4))) +
       annotation_scale(unit_category = "imperial", plot_unit = "ft", width_hint = 0.6, pad_x = unit(0, "cm")) +
-      labs(caption = "mixing imperial units") +
-      coord_fixed(expand = FALSE)
+      ggplot2::coord_fixed(expand = FALSE)
   )
 
-  print(
+  vdiffr::expect_doppelganger(
+    "scale bar (imperial unit)",
     ggplot() +
-      geom_point(aes(x, y), data = data.frame(x = 0:15, y = -(0:15))) +
+      ggplot2::geom_point(aes(x, y), data = data.frame(x = 0:15, y = -(0:15))) +
       annotation_scale(unit_category = "imperial", plot_unit = "ft", width_hint = 0.7, pad_x = unit(0, "cm")) +
-      labs(caption = "imperial units") +
-      coord_fixed(expand = FALSE)
+      ggplot2::coord_fixed(expand = FALSE)
   )
 
   # position
-  print(
+  vdiffr::expect_doppelganger(
+    "scale bar (defaults, bottom left)",
     ggplot() +
       geom_sf(data = longlake_depthdf) +
-      annotation_scale(location = "bl") +
-      labs(caption = "defaults for annotation_scale(), legend bottom left")
+      annotation_scale(location = "bl")
   )
 
-  print(
+  vdiffr::expect_doppelganger(
+    "scale bar (defaults, bottom right)",
     ggplot() +
       geom_sf(data = longlake_depthdf) +
-      annotation_scale(location = "br") +
-      labs(caption = "defaults for annotation_scale(), legend bottom right")
+      annotation_scale(location = "br")
   )
 
-  print(
+  vdiffr::expect_doppelganger(
+    "scale bar (defaults, top left)",
     ggplot() +
       geom_sf(data = longlake_depthdf) +
-      annotation_scale(location = "tl") +
-      labs(caption = "defaults for annotation_scale(), legend top left")
+      annotation_scale(location = "tl")
   )
 
-  print(
+  vdiffr::expect_doppelganger(
+    "scale bar (defaults, top right)",
     ggplot() +
       geom_sf(data = longlake_depthdf) +
-      annotation_scale(location = "tr") +
-      labs(caption = "defaults for annotation_scale(), legend top right")
+      annotation_scale(location = "tr")
   )
 
   # styles
-  print(
+  vdiffr::expect_doppelganger(
+    "scale bar (ticks)",
     ggplot() +
-      geom_point(aes(x, y), data = data.frame(x = 0:4, y = -(0:4))) +
+      ggplot2::geom_point(aes(x, y), data = data.frame(x = 0:4, y = -(0:4))) +
       annotation_scale(plot_unit = "m", style = "ticks") +
-      labs(caption = "ticks style scale") +
-      coord_fixed()
+      ggplot2::coord_fixed()
   )
-
 })
 
 test_that("font items are passed on to annotation_scale()", {
-  print(
+  vdiffr::expect_doppelganger(
+    "scale bar (fonts)",
     ggplot() +
-      geom_point(aes(x, y), data = data.frame(x = 0:4, y = -(0:4))) +
+      ggplot2::geom_point(aes(x, y), data = data.frame(x = 0:4, y = -(0:4))) +
       annotation_scale(plot_unit = "m", text_face = "bold") +
       annotation_scale(plot_unit = "m", pad_y = unit(1, "cm")) +
       annotation_scale(plot_unit = "m", pad_y = unit(2, "cm"), text_family = "serif") +
-      labs(caption = "serif label, default label, bold label") +
-      coord_fixed()
+      ggplot2::coord_fixed()
   )
-
-  expect_true(TRUE)
 })
 
 
@@ -149,7 +146,7 @@ test_that("certain parameters can be passed as aesthetics to show up on differen
     facet_var = c("one", "two", "three", "four"),
     data = list(data.frame(x = 0:4, y = -(0:4)))
   ) %>%
-    tidyr::unnest()
+    tidyr::unnest(data)
 
   scale_params <- tibble::tibble(
     facet_var = c("one", "two", "three"),
@@ -161,20 +158,17 @@ test_that("certain parameters can be passed as aesthetics to show up on differen
     line_col = c("black", "red", "blue")
   )
 
-  print(
+  vdiffr::expect_doppelganger(
+    "scale bar (parameters as aesthetics)",
     ggplot(df) +
-      geom_point(aes(x, y)) +
+      ggplot2::geom_point(aes(x, y)) +
       annotation_scale(
         aes(width_hint = width_hint, style = style, location = location, unit_category = unit_category,
             text_col = text_col, line_col = line_col),
         data = scale_params,
         plot_unit = "m"
       ) +
-      facet_wrap(~facet_var) +
-      coord_fixed() +
-      labs(caption = "three scale bars in different panels with different parameters")
+      ggplot2::facet_wrap(~facet_var) +
+      ggplot2::coord_fixed()
   )
-
-  # visual test
-  expect_true(TRUE)
 })
